feature_frameTransform_custom_config {#master}
-------------------

### Devices

#### `frameTransformServer` `frameTransformClient`

* Added the option to use an extern xml file (by providing its absolute path) to configure the `frameTransformServer` and the `frameTransformClient` devices.
* **NB:** this function is intended for TEST ONLY
